@@ -11,12 +11,7 @@
 #include <string.h>
 #include <asm/unistd.h>
 
-#ifndef __ia64 /* breaks ia64. */
-_syscall2(long, create_module, const char *, name, size_t, size);
-#else
-#define create_module(name, size) \
-	syscall(__NR_create_module, (name), (size))
-#endif
+extern long create_module(const char *, size_t);
 
 #include "testing.h"
 
