@@ -43,9 +43,13 @@
 #define ARRAY_SIZE(x) (sizeof(x) / sizeof((x)[0]))
 
 #include "zlibsupport.h"
+#include "logging.h"
+#include "index.h"
 #include "list.h"
 #include "backwards_compat.c"
 
+int use_binary_indexes = 1; /* default to enabled. */
+
 extern long init_module(void *, unsigned long, const char *);
 extern long delete_module(const char *, unsigned int);
 
@@ -61,61 +65,12 @@ struct module {
 
 typedef void (*errfn_t)(const char *fmt, ...);
 
-/* Do we use syslog or stderr for messages? */
-static int log;
-
-static void message(const char *prefix, const char *fmt, va_list *arglist)
-{
-	char *buf, *buf2;
-
-	vasprintf(&buf, fmt, *arglist);
-	asprintf(&buf2, "%s%s", prefix, buf);
-
-	if (log)
-		syslog(LOG_NOTICE, "%s", buf2);
-	else
-		fprintf(stderr, "%s", buf2);
-	free(buf2);
-	free(buf);
-}
-
-static int warned = 0;
-static void warn(const char *fmt, ...)
-{
-	va_list arglist;
-	warned++;
-	va_start(arglist, fmt);
-	message("WARNING: ", fmt, &arglist);
-	va_end(arglist);
-}
-
-static void fatal(const char *fmt, ...)
-{
-	va_list arglist;
-	va_start(arglist, fmt);
-	message("FATAL: ", fmt, &arglist);
-	va_end(arglist);
-	exit(1);
-}
-
-
 static void grammar(const char *cmd, const char *filename, unsigned int line)
 {
 	warn("%s line %u: ignoring bad line starting with '%s'\n",
 	     filename, line, cmd);
 }
 
-static void *do_nofail(void *ptr, const char *file, int line, const char *expr)
-{
-	if (!ptr) {
-		fatal("Memory allocation failure %s line %d: %s.\n",
-		      file, line, expr);
-	}
-	return ptr;
-}
-
-#define NOFAIL(ptr)	do_nofail((ptr), __FILE__, __LINE__, #ptr)
-
 static void print_usage(const char *progname)
 {
 	fprintf(stderr,
@@ -126,42 +81,48 @@ static void print_usage(const char *progname)
 	exit(1);
 }
 
-static int fgetc_wrapped(FILE *file, unsigned int *linenum)
-{
-	for (;;) {
-	  	int ch = fgetc(file);
-		if (ch != '\\')
-			return ch;
-		ch = fgetc(file);
-		if (ch != '\n')
-			return ch;
-		if (linenum)
-			(*linenum)++;
-	}
-}
-
 static char *getline_wrapped(FILE *file, unsigned int *linenum)
 {
-	int size = 1024;
+	int size = 256;
 	int i = 0;
 	char *buf = NOFAIL(malloc(size));
 	for(;;) {
-		int ch = fgetc_wrapped(file, linenum);
-		if (i == size) {
-			size *= 2;
-			buf = NOFAIL(realloc(buf, size));
-		}
-		if (ch < 0 && i == 0) {
-			free(buf);
-			return NULL;
-		}
-		if (ch < 0 || ch == '\n') {
+		int ch = getc_unlocked(file);
+		
+		switch(ch) {
+		case EOF:
+			if (i == 0) {
+				free(buf);
+				return NULL;
+			}
+			/* else fall through */
+			
+		case '\n':
 			if (linenum)
 				(*linenum)++;
+			if (i == size)
+				buf = NOFAIL(realloc(buf, size + 1));
 			buf[i] = '\0';
-			return NOFAIL(realloc(buf, i+1));
+			return buf;
+			
+		case '\\':
+			ch = getc_unlocked(file);
+			
+			if (ch == '\n') {
+				if (linenum)
+					(*linenum)++;
+				continue;
+			}
+			/* else fall through */
+		
+		default:
+			buf[i++] = ch;
+	
+			if (i == size) {
+				size *= 2;
+				buf = NOFAIL(realloc(buf, size));
+			}
 		}
-		buf[i++] = ch;
 	}
 }
 
@@ -303,6 +264,35 @@ static int add_modules_dep_line(char *line,
 	return 1;
 }
 
+static int read_depends_bin(const char *dirname,
+			 const char *start_name,
+			 struct list_head *list)
+{
+	char *modules_dep_name;
+	char *line;
+	FILE *modules_dep;
+
+	asprintf(&modules_dep_name, "%s/%s", dirname, "modules.dep.bin");
+	modules_dep = fopen(modules_dep_name, "r");
+	if (!modules_dep) {
+		free(modules_dep_name);
+		return 0;
+	}
+
+	line = index_search(modules_dep, start_name);
+	if (line) {
+		/* Value is standard dependency line format */
+		if (!add_modules_dep_line(line, start_name, list))
+			fatal("Module index is inconsistent\n");
+		free(line);
+	}
+	
+	fclose(modules_dep);
+	free(modules_dep_name);
+	
+	return 1;
+}
+
 static void read_depends(const char *dirname,
 			 const char *start_name,
 			 struct list_head *list)
@@ -312,6 +302,9 @@ static void read_depends(const char *dirname,
 	FILE *modules_dep;
 	int done = 0;
 
+	if (read_depends_bin(dirname, start_name, list))
+		return;
+
 	asprintf(&modules_dep_name, "%s/%s", dirname, "modules.dep");
 	modules_dep = fopen(modules_dep_name, "r");
 	if (!modules_dep)
@@ -891,8 +884,12 @@ static void insmod(struct list_head *list,
 				      newname ?: mod->modname);
 			goto out_unlock;
 		}
-		error("Error inserting %s (%s): %s\n",
-		      mod->modname, mod->filename, insert_moderror(errno));
+		/* don't warn noisely if we're loading multiple aliases. */
+		/* one of the aliases may try to use hardware we don't have. */
+		if ((error != warn) || (verbose))
+			error("Error inserting %s (%s): %s\n",
+			      mod->modname, mod->filename,
+			      insert_moderror(errno));
 	}
  out:
 	release_file(map, len);
@@ -977,6 +974,67 @@ nonexistent_module:
 	goto remove_rest;
 }
 
+struct modver32_info
+{
+       uint32_t crc;
+       char name[64 - sizeof(uint32_t)];
+};
+
+struct modver64_info
+{
+       uint64_t crc;
+       char name[64 - sizeof(uint64_t)];
+};
+
+const char *skip_dot(const char *str)
+{
+       /* For our purposes, .foo matches foo.  PPC64 needs this. */
+       if (str && str[0] == '.')
+               return str + 1;
+       return str;
+}
+
+void dump_modversions(const char *filename, errfn_t error)
+{
+       unsigned long size, secsize;
+       void *file = grab_file(filename, &size);
+       struct modver32_info *info32;
+       struct modver64_info *info64;
+       int n;
+
+       if (!file) {
+               error("%s: %s\n", filename, strerror(errno));
+               return;
+       }
+       switch (elf_ident(file, size)) {
+       case ELFCLASS32:
+               info32 = get_section32(file, size, "__versions", &secsize);
+               if (!info32)
+                       return;  /* Does not seem to be a kernel module */
+               if (secsize % sizeof(struct modver32_info))
+                       error("Wrong section size in %s\n", filename);
+               for (n = 0; n < secsize / sizeof(struct modver32_info); n++)
+                       printf("0x%08lx\t%s\n", (unsigned long)
+                              info32[n].crc, skip_dot(info32[n].name));
+               break;
+
+       case ELFCLASS64:
+               info64 = get_section64(file, size, "__versions", &secsize);
+               if (!info64)
+                       return;  /* Does not seem to be a kernel module */
+               if (secsize % sizeof(struct modver64_info))
+                       error("Wrong section size in %s\n", filename);
+               for (n = 0; n < secsize / sizeof(struct modver64_info); n++)
+                       printf("0x%08llx\t%s\n", (unsigned long long)
+                              info64[n].crc, skip_dot(info64[n].name));
+               break;
+
+       default:
+               error("%s: ELF class not recognized\n", filename);
+       }
+}
+
+
 /* Does path contain directory(s) subpath? */
 static int type_matches(const char *path, const char *subpath)
 {
@@ -1103,8 +1161,10 @@ static int read_config_file(const char *filename,
 			printf("%s\n", line);
 
 		cmd = strsep_skipspace(&ptr, "\t ");
-		if (cmd == NULL || cmd[0] == '#' || cmd[0] == '\0')
+		if (cmd == NULL || cmd[0] == '#' || cmd[0] == '\0') {
+			free(line);
 			continue;
+		}
 
 		if (strcmp(cmd, "alias") == 0) {
 			char *wildcard
@@ -1172,6 +1232,15 @@ static int read_config_file(const char *filename,
 				*commands = add_command(underscores(modname),
 							ptr, *commands);
 			}
+		} else if (strcmp(cmd, "config") == 0) {
+			char *tmp = strsep_skipspace(&ptr, "\t ");
+			if (strcmp(tmp, "binary_indexes") == 0) {
+				tmp = strsep_skipspace(&ptr, "\t ");
+				if (strcmp(tmp, "yes") == 0)
+					use_binary_indexes = 1;
+				if (strcmp(tmp, "no") == 0)
+					use_binary_indexes = 0;
+			}
 		} else
 			grammar(cmd, filename, linenum);
 
@@ -1224,6 +1293,51 @@ static int read_config(const char *filename,
 	return ret;
 }
 
+/* Read binary index file containing aliases only */
+/* fallback to legacy aliases file as necessary */
+static int read_config_file_bin(const char *filename,
+			    const char *name,
+			    int dump_only,
+			    int removing,
+			    struct module_options **options,
+			    struct module_command **commands,
+			    struct module_alias **aliases,
+			    struct module_blacklist **blacklist)
+{
+	struct index_value *realname;
+	char *binfile;
+	FILE *cfile;
+
+	asprintf(&binfile, "%s.bin", filename);
+	cfile = fopen(binfile, "r");
+	if (!cfile) {
+		free(binfile);
+		
+		return read_config_file(filename, name, dump_only, removing,
+					options, commands, aliases, blacklist);
+	}
+
+	if (dump_only) {
+		index_dump(cfile, stdout, "alias ");
+		free(binfile);
+		fclose(cfile);
+		return 1;
+	}
+	
+	realname = index_searchwild(cfile, name);
+	while(realname) {
+		struct index_value *next = realname->next;
+		*aliases = add_alias(realname->value, *aliases);
+		
+		free(realname);
+		realname = next;
+	}
+	
+	free(binfile);
+	fclose(cfile);
+	return 1;
+}
+
 static const char *default_configs[] = 
 {
 	"/etc/modprobe.conf",
@@ -1251,9 +1365,8 @@ static void read_toplevel_config(const char *filename,
 
 	/* Try defaults. */
 	for (i = 0; i < ARRAY_SIZE(default_configs); i++) {
-		if (read_config(default_configs[i], name, dump_only, removing,
-				options, commands, aliases, blacklist))
-			return;
+		read_config(default_configs[i], name, dump_only, removing,
+				options, commands, aliases, blacklist);
 	}
 }
 
@@ -1428,6 +1541,7 @@ static struct option options[] = { { "verbose", 0, NULL, 'v' },
 				   { "set-version", 1, NULL, 'S' },
 				   { "show-depends", 0, NULL, 'D' },
 				   { "first-time", 0, NULL, 3 },
+				   { "dump-modversions", 0, NULL, 4 },
 				   { "use-blacklist", 0, NULL, 'b' },
 				   { NULL, 0, NULL, 0 } };
 
@@ -1465,6 +1579,7 @@ int main(int argc, char *argv[])
 	int strip_modversion = 0;
 	int ignore_proc = 0;
 	int first_time = 0;
+	int dump_modver = 0;
 	int use_blacklist = 0;
 	unsigned int i, num_modules;
 	char *type = NULL;
@@ -1561,7 +1676,7 @@ int main(int argc, char *argv[])
 			break;
 		case 's':
 			add_to_env_var("-s");
-			log = 1;
+			logging = 1;
 			break;
 		case 'i':
 			ignore_commands = 1;
@@ -1585,15 +1700,18 @@ int main(int argc, char *argv[])
 		case 3:
 			first_time = 1;
 			break;
+		case 4:
+			dump_modver = 1;
+			break;
 		default:
 			print_usage(argv[0]);
 		}
 	}
 
 	/* If stderr not open, go to syslog */
-	if (log || fstat(STDERR_FILENO, &statbuf) != 0) {
+	if (logging || fstat(STDERR_FILENO, &statbuf) != 0) {
 		openlog("modprobe", LOG_CONS, LOG_DAEMON);
-		log = 1;
+		logging = 1;
 	}
 
 	if (argc < optind + 1 && !dump_only && !list_only && !remove)
@@ -1627,10 +1745,17 @@ int main(int argc, char *argv[])
 		read_toplevel_config(config, "", 1, 0,
 			     &modoptions, &commands, &aliases, &blacklist);
 		read_kcmdline(1, &modoptions);
-		read_config(aliasfilename, "", 1, 0,&modoptions, &commands,
-			    &aliases, &blacklist);
-		read_config(symfilename, "", 1, 0, &modoptions, &commands,
-			    &aliases, &blacklist);
+		if (use_binary_indexes) {
+			read_config_file_bin(aliasfilename, "", 1, 0,
+			     &modoptions, &commands, &aliases, &blacklist);
+			read_config_file_bin(symfilename, "", 1, 0,
+			     &modoptions, &commands, &aliases, &blacklist);
+		} else {
+			read_config(aliasfilename, "", 1, 0,
+			     &modoptions, &commands, &aliases, &blacklist);
+			read_config(symfilename, "", 1, 0,
+			     &modoptions, &commands, &aliases, &blacklist);
+		}
 		exit(0);
 	}
 
@@ -1651,6 +1776,11 @@ int main(int argc, char *argv[])
 		LIST_HEAD(list);
 		char *modulearg = argv[optind + i];
 
+		if (dump_modver) {
+			dump_modversions(modulearg, error);
+			continue;
+		}
+
 		/* Convert name we are looking for */
 		underscores(modulearg);
 
@@ -1663,21 +1793,34 @@ int main(int argc, char *argv[])
 
 		/* No luck?  Try symbol names, if starts with symbol:. */
 		if (!aliases
-		    && strncmp(modulearg, "symbol:", strlen("symbol:")) == 0)
-			read_config(symfilename, modulearg, 0,
-			    remove, &modoptions, &commands,
-			    	&aliases, &blacklist);
-
+		    && strncmp(modulearg, "symbol:", strlen("symbol:")) == 0) {
+			if (use_binary_indexes)
+				read_config_file_bin(symfilename, modulearg, 0,
+					remove, &modoptions, &commands,
+					&aliases, &blacklist);
+			else
+				read_config(symfilename, modulearg, 0,
+					remove, &modoptions, &commands,
+					&aliases, &blacklist);
+		}
 		if (!aliases) {
-			/* We only use canned aliases as last resort. */
-			read_depends(dirname, modulearg, &list);
+			if(!strchr(modulearg, ':'))
+				read_depends(dirname, modulearg, &list);
 
+			/* We only use canned aliases as last resort. */
 			if (list_empty(&list)
 			    && !find_command(modulearg, commands))
 			{
-				read_config(aliasfilename, modulearg, 0,
-					    remove, &modoptions, &commands,
-					    &aliases, &blacklist);
+				if (use_binary_indexes)
+					read_config_file_bin(aliasfilename,
+						modulearg, 0, remove,
+						&modoptions, &commands,
+						&aliases, &blacklist);
+				else
+					read_config(aliasfilename,
+						modulearg, 0, remove,
+						&modoptions, &commands,
+						&aliases, &blacklist);
 			}
 		}
 
@@ -1720,8 +1863,13 @@ int main(int argc, char *argv[])
 				      unknown_silent, optstring, flags);
 		}
 	}
-	if (log)
+	if (logging)
 		closelog();
 
+	free(dirname);
+	free(aliasfilename);
+	free(symfilename);
+	free(optstring);
+	
 	return 0;
 }
