@@ -122,6 +122,30 @@ MODTEST_OVERRIDE29=/lib/modules/$MODTEST_UNAME/modules.ofmap
 MODTEST_OVERRIDE_WITH29=tests/tmp/modules.ofmap
 export MODTEST_OVERRIDE29 MODTEST_OVERRIDE_WITH29
 
+MODTEST_OVERRIDE30=/lib/modules/$MODTEST_UNAME/modules.dep.bin
+MODTEST_OVERRIDE_WITH30=tests/tmp/modules.dep.bin
+export MODTEST_OVERRIDE30 MODTEST_OVERRIDE_WITH30
+
+MODTEST_OVERRIDE31=/lib/modules/$MODTEST_UNAME/modules.dep.bin.temp
+MODTEST_OVERRIDE_WITH31=tests/tmp/modules.dep.bin.temp
+export MODTEST_OVERRIDE31 MODTEST_OVERRIDE_WITH31
+
+MODTEST_OVERRIDE32=/lib/modules/$MODTEST_UNAME/modules.alias.bin.temp
+MODTEST_OVERRIDE_WITH32=tests/tmp/modules.alias.bin.temp
+export MODTEST_OVERRIDE32 MODTEST_OVERRIDE_WITH32
+
+MODTEST_OVERRIDE33=/lib/modules/$MODTEST_UNAME/modules.alias.bin
+MODTEST_OVERRIDE_WITH33=tests/tmp/modules.alias.bin
+export MODTEST_OVERRIDE33 MODTEST_OVERRIDE_WITH33
+
+MODTEST_OVERRIDE34=/lib/modules/$MODTEST_UNAME/modules.symbols.bin
+MODTEST_OVERRIDE_WITH34=tests/tmp/modules.symbols.bin
+export MODTEST_OVERRIDE34 MODTEST_OVERRIDE_WITH34
+
+MODTEST_OVERRIDE35=/lib/modules/$MODTEST_UNAME/modules.symbols.bin.temp
+MODTEST_OVERRIDE_WITH35=tests/tmp/modules.symbols.bin.temp
+export MODTEST_OVERRIDE35 MODTEST_OVERRIDE_WITH35
+
 # Temporary file.
 MODTEST_OVERRIDE27=/lib/modules/$MODTEST_UNAME/README
 MODTEST_OVERRIDE_WITH27=tests/tmp/data/$BITNESS$ENDIAN/normal/README
@@ -129,7 +153,7 @@ export MODTEST_OVERRIDE27 MODTEST_OVERRIDE_WITH27
 
 # First time, there is no modules.dep, so it will be generated.
 # Expect no output.
-[ "`depmod -A 2>&1`" = "" ]
+[ "`./depmod -A 2>&1`" = "" ]
 
 # Check modules.dep results: expect 5 lines
 [ `grep -vc '^#' < tests/tmp/modules.dep` = 5 ]
@@ -153,7 +177,7 @@ cp tests/tmp/modules.symbols tests/tmp/modules.symbols.old
 # Now, second run should do nothing.
 cp /dev/null tests/tmp/modules.dep
 cp /dev/null tests/tmp/modules.symbols
-[ "`depmod -A 2>&1`" = "" ]
+[ "`./depmod -A 2>&1`" = "" ]
 diff -u /dev/null tests/tmp/modules.dep
 diff -u /dev/null tests/tmp/modules.symbols
 
@@ -161,19 +185,19 @@ diff -u /dev/null tests/tmp/modules.symbols
 sleep 1
 touch tests/tmp/data/$BITNESS$ENDIAN/normal
 
-[ "`depmod -A 2>&1`" = "" ]
+[ "`./depmod -A 2>&1`" = "" ]
 diff -u /dev/null tests/tmp/modules.dep
 diff -u /dev/null tests/tmp/modules.symbols
 
 # Touch a non-module, nothing.
 echo "Test" > tests/tmp/data/$BITNESS$ENDIAN/normal/README
-[ "`depmod -A 2>&1`" = "" ]
+[ "`./depmod -A 2>&1`" = "" ]
 diff -u /dev/null tests/tmp/modules.dep
 diff -u /dev/null tests/tmp/modules.symbols
 
 # Touch a module, wham.
 touch tests/tmp/data/$BITNESS$ENDIAN/normal/noexport_doubledep-$BITNESS.ko
-[ "`depmod -A 2>&1`" = "" ]
+[ "`./depmod -A 2>&1`" = "" ]
 diff -u tests/tmp/modules.dep.old tests/tmp/modules.dep
 diff -u tests/tmp/modules.symbols.old tests/tmp/modules.symbols
 
@@ -181,7 +205,7 @@ diff -u tests/tmp/modules.symbols.old tests/tmp/modules.symbols
 cp /dev/null tests/tmp/modules.dep
 cp /dev/null tests/tmp/modules.symbols
 rm tests/tmp/data/$BITNESS$ENDIAN/normal/noexport_doubledep-$BITNESS.ko
-[ "`depmod -A 2>&1`" = "" ]
+[ "`./depmod -A 2>&1`" = "" ]
 diff -u /dev/null tests/tmp/modules.dep
 diff -u /dev/null tests/tmp/modules.symbols
 
