@@ -45,6 +45,10 @@ MODTEST_OVERRIDE28=/lib/modules/$MODTEST_UNAME/of_map-$BITNESS.ko.gz
 MODTEST_OVERRIDE_WITH28=tests/tmp/data/of_map-$BITNESS.ko.gz
 export MODTEST_OVERRIDE28 MODTEST_OVERRIDE_WITH28
 
+MODTEST_OVERRIDE31=/lib/modules/$MODTEST_UNAME/input_map_new-$BITNESS.ko.gz
+MODTEST_OVERRIDE_WITH31=tests/tmp/data/input_map_new-$BITNESS.ko.gz
+export MODTEST_OVERRIDE31 MODTEST_OVERRIDE_WITH31
+
 # Outputs
 MODTEST_OVERRIDE7=/lib/modules/$MODTEST_UNAME/modules.dep
 MODTEST_OVERRIDE_WITH7=tests/tmp/modules.dep
@@ -135,8 +139,32 @@ MODTEST_OVERRIDE30=/lib/modules/$MODTEST_UNAME/modules.ofmap
 MODTEST_OVERRIDE_WITH30=tests/tmp/modules.ofmap
 export MODTEST_OVERRIDE30 MODTEST_OVERRIDE_WITH30
 
+MODTEST_OVERRIDE32=/lib/modules/$MODTEST_UNAME/modules.dep.bin
+MODTEST_OVERRIDE_WITH32=tests/tmp/modules.dep.bin
+export MODTEST_OVERRIDE32 MODTEST_OVERRIDE_WITH32
+
+MODTEST_OVERRIDE33=/lib/modules/$MODTEST_UNAME/modules.dep.bin.temp
+MODTEST_OVERRIDE_WITH33=tests/tmp/modules.dep.bin.temp
+export MODTEST_OVERRIDE33 MODTEST_OVERRIDE_WITH33
+
+MODTEST_OVERRIDE34=/lib/modules/$MODTEST_UNAME/modules.alias.bin.temp
+MODTEST_OVERRIDE_WITH34=tests/tmp/modules.alias.bin.temp
+export MODTEST_OVERRIDE34 MODTEST_OVERRIDE_WITH34
+
+MODTEST_OVERRIDE35=/lib/modules/$MODTEST_UNAME/modules.alias.bin
+MODTEST_OVERRIDE_WITH35=tests/tmp/modules.alias.bin
+export MODTEST_OVERRIDE35 MODTEST_OVERRIDE_WITH35
+
+MODTEST_OVERRIDE36=/lib/modules/$MODTEST_UNAME/modules.symbols.bin
+MODTEST_OVERRIDE_WITH36=tests/tmp/modules.symbols.bin
+export MODTEST_OVERRIDE36 MODTEST_OVERRIDE_WITH36
+
+MODTEST_OVERRIDE37=/lib/modules/$MODTEST_UNAME/modules.symbols.bin.temp
+MODTEST_OVERRIDE_WITH37=tests/tmp/modules.symbols.bin.temp
+export MODTEST_OVERRIDE37 MODTEST_OVERRIDE_WITH37
+
 # Expect no output.
-[ "`depmod`" = "" ]
+[ "`./depmod`" = "" ]
 
 # Check PCI: expect 2 lines
 [ `grep -vc '^#' < tests/tmp/modules.pcimap` = 2 ]
@@ -165,12 +193,17 @@ ccw_map-$BITNESS           0x000f      0x000b  0x0d      0x000c  0x0e" ]
 [ "`grep ieee1394_map tests/tmp/modules.ieee1394map`" = "ieee1394_map-$BITNESS      0x0000000c  0x000000  0x000000 0x00a02d     0x010001
 ieee1394_map-$BITNESS      0x0000000c  0x000000  0x000000 0x00a02d     0x000100" ]
 
-# Check input: expect 2 lines
-[ `grep -vc '^#' < tests/tmp/modules.inputmap` = 2 ]
+# Check input: expect 4 lines
+[ `grep -vc '^#' < tests/tmp/modules.inputmap` = 4 ]
 
-# module         matchBits bustype vendor product version evBits keyBits relBits absBits mscBits ledBits sndBits ffBits driver_info
-[ "`grep input_map tests/tmp/modules.inputmap`" = "input_map-$BITNESS        0x10  0x0  0x0  0x0  0x0  2  0  0  0  0  0  0  0  0x0
-input_map-$BITNESS        0x10  0x0  0x0  0x0  0x0  40000  0  0  0  0  0  0  0  0x0" ]
+# module         matchBits bustype vendor product version evBits keyBits relBits absBits mscBits ledBits sndBits ffBits [swBits] driver_info
+[ "`grep input_map tests/tmp/modules.inputmap`" = "input_map_new-$BITNESS    0x1010  0x0  0x0  0x0  0x0  2  0  0  0  0  0  0  0  1  0x0
+input_map_new-$BITNESS    0x10  0x0  0x0  0x0  0x0  40000  0  0  0  0  0  0  0  0  0x0
+input_map-$BITNESS        0x10  0x0  0x0  0x0  0x0  2  0  0  0  0  0  0  0  0x0
+input_map-$BITNESS        0x10  0x0  0x0  0x0  0x0  40000  0  0  0  0  0  0  0  0x0" ] || [ "`grep input_map tests/tmp/modules.inputmap`" = "input_map-$BITNESS        0x10  0x0  0x0  0x0  0x0  2  0  0  0  0  0  0  0  0x0
+input_map-$BITNESS        0x10  0x0  0x0  0x0  0x0  40000  0  0  0  0  0  0  0  0x0
+input_map_new-$BITNESS    0x1010  0x0  0x0  0x0  0x0  2  0  0  0  0  0  0  0  1  0x0
+input_map_new-$BITNESS    0x10  0x0  0x0  0x0  0x0  40000  0  0  0  0  0  0  0  0  0x0" ]
 
 # Check of: expect 7 lines
 [ `grep -vc '^#' < tests/tmp/modules.ofmap` = 7 ]
@@ -194,7 +227,7 @@ mv tests/tmp/modules.inputmap tests/tmp/modules.inputmap.old
 mv tests/tmp/modules.ofmap tests/tmp/modules.ofmap.old
 
 # Synonyms
-[ "`depmod -a`" = "" ]
+[ "`./depmod -a`" = "" ]
 diff -u tests/tmp/modules.dep.old tests/tmp/modules.dep
 diff -u tests/tmp/modules.pcimap.old tests/tmp/modules.pcimap
 diff -u tests/tmp/modules.usbmap.old tests/tmp/modules.usbmap
@@ -204,7 +237,7 @@ diff -u tests/tmp/modules.isapnpmap.old tests/tmp/modules.isapnpmap
 diff -u tests/tmp/modules.inputmap.old tests/tmp/modules.inputmap
 diff -u tests/tmp/modules.ofmap.old tests/tmp/modules.ofmap
 
-[ "`depmod -A`" = "" ]
+[ "`./depmod -A`" = "" ]
 diff -u tests/tmp/modules.dep.old tests/tmp/modules.dep
 diff -u tests/tmp/modules.pcimap.old tests/tmp/modules.pcimap
 diff -u tests/tmp/modules.usbmap.old tests/tmp/modules.usbmap
@@ -214,7 +247,7 @@ diff -u tests/tmp/modules.isapnpmap.old tests/tmp/modules.isapnpmap
 diff -u tests/tmp/modules.inputmap.old tests/tmp/modules.inputmap
 diff -u tests/tmp/modules.ofmap.old tests/tmp/modules.ofmap
 
-[ "`depmod -e -A`" = "" ]
+[ "`./depmod -e -A`" = "" ]
 diff -u tests/tmp/modules.dep.old tests/tmp/modules.dep
 diff -u tests/tmp/modules.pcimap.old tests/tmp/modules.pcimap
 diff -u tests/tmp/modules.usbmap.old tests/tmp/modules.usbmap
@@ -224,7 +257,7 @@ diff -u tests/tmp/modules.isapnpmap.old tests/tmp/modules.isapnpmap
 diff -u tests/tmp/modules.inputmap.old tests/tmp/modules.inputmap
 diff -u tests/tmp/modules.ofmap.old tests/tmp/modules.ofmap
 
-[ "`depmod -e -A $MODTEST_VERSION`" = "" ]
+[ "`./depmod -e -A $MODTEST_VERSION`" = "" ]
 diff -u tests/tmp/modules.dep.old tests/tmp/modules.dep
 diff -u tests/tmp/modules.pcimap.old tests/tmp/modules.pcimap
 diff -u tests/tmp/modules.usbmap.old tests/tmp/modules.usbmap
@@ -238,16 +271,16 @@ diff -u tests/tmp/modules.ofmap.old tests/tmp/modules.ofmap
 grep -hv '^#' tests/tmp/modules.dep.old tests/tmp/modules.pcimap.old tests/tmp/modules.usbmap.old tests/tmp/modules.ccwmap.old tests/tmp/modules.ieee1394map.old tests/tmp/modules.isapnpmap.old tests/tmp/modules.inputmap.old tests/tmp/modules.ofmap.old > tests/tmp/out
 
 # Stdout versions.
-depmod -n | grep -v '^#' > tests/tmp/stdout
+./depmod -n | grep -v '^#' > tests/tmp/stdout
 diff -u tests/tmp/out tests/tmp/stdout
 
-depmod -a -n | grep -v '^#' > tests/tmp/modules.dep
+./depmod -a -n | grep -v '^#' > tests/tmp/modules.dep
 diff -u tests/tmp/out tests/tmp/stdout
 
-depmod -n -a $MODTEST_VERSION | grep -v '^#' > tests/tmp/modules.dep
+./depmod -n -a $MODTEST_VERSION | grep -v '^#' > tests/tmp/modules.dep
 diff -u tests/tmp/out tests/tmp/stdout
 
-depmod -e -n -A $MODTEST_VERSION | grep -v '^#' > tests/tmp/modules.dep
+./depmod -e -n -A $MODTEST_VERSION | grep -v '^#' > tests/tmp/modules.dep
 diff -u tests/tmp/out tests/tmp/stdout
 
 done
