@@ -26,10 +26,13 @@ MODTEST_OVERRIDE6=/etc/modprobe2.conf
 MODTEST_OVERRIDE_WITH6=tests/tmp/modprobe2.conf
 export MODTEST_OVERRIDE6 MODTEST_OVERRIDE_WITH6
 
+MODTEST_OVERRIDE7=/lib/modules/2.5.53/modules.dep.bin
+MODTEST_OVERRIDE_WITH7=FILE-WHICH-DOESNT-EXIST
+export MODTEST_OVERRIDE7 MODTEST_OVERRIDE_WITH7
 # Now create modules.dep and modules.conf
 echo /lib/modules/2.5.52/noexport_nodep-$BITNESS.ko: > tests/tmp/modules.dep
-echo install foo modprobe noexport_nodep-$BITNESS > tests/tmp/modprobe.conf
-echo install foo modprobe bar > tests/tmp/modprobe2.conf
+echo install foo ./modprobe noexport_nodep-$BITNESS > tests/tmp/modprobe.conf
+echo install foo ./modprobe bar > tests/tmp/modprobe2.conf
 echo install bar echo DOING BAR >> tests/tmp/modprobe2.conf
 
 SIZE_NOEXPORT_NODEP=$(echo `wc -c < tests/data/$BITNESS/normal/noexport_nodep-$BITNESS.ko`)
@@ -53,20 +56,20 @@ INIT_MODULE: $SIZE_NOEXPORT_NODEP " ]
 MODTEST_DO_SYSTEM=1
 export MODTEST_DO_SYSTEM
 
-[ "`./modprobe -v foo 2>&1`" = "install modprobe noexport_nodep-$BITNESS
+[ "`./modprobe -v foo 2>&1`" = "install ./modprobe noexport_nodep-$BITNESS
 insmod /lib/modules/2.5.52/noexport_nodep-$BITNESS.ko 
 INIT_MODULE: $SIZE_NOEXPORT_NODEP " ]
-[ "`MODPROBE_OPTIONS=-v ./modprobe foo 2>&1`" = "install modprobe noexport_nodep-$BITNESS
+[ "`MODPROBE_OPTIONS=-v ./modprobe foo 2>&1`" = "install ./modprobe noexport_nodep-$BITNESS
 insmod /lib/modules/2.5.52/noexport_nodep-$BITNESS.ko 
 INIT_MODULE: $SIZE_NOEXPORT_NODEP " ]
 
 [ "`./modprobe -C /etc/modprobe2.conf foo 2>&1`" = "DOING BAR" ]
 [ "`MODPROBE_OPTIONS='-C /etc/modprobe2.conf' ./modprobe foo 2>&1`" = "DOING BAR" ]
 
-[ "`./modprobe -C /etc/modprobe2.conf -v foo 2>&1`" = "install modprobe bar
+[ "`./modprobe -C /etc/modprobe2.conf -v foo 2>&1`" = "install ./modprobe bar
 install echo DOING BAR
 DOING BAR" ]
-[ "`MODPROBE_OPTIONS='-C /etc/modprobe2.conf' ./modprobe -v foo 2>&1`" = "install modprobe bar
+[ "`MODPROBE_OPTIONS='-C /etc/modprobe2.conf' ./modprobe -v foo 2>&1`" = "install ./modprobe bar
 install echo DOING BAR
 DOING BAR" ]
 done
